@@ -32,6 +32,8 @@ LOAD_BALANCER_ROWS = (
     'vip_port_id',
     'vip_qos_policy_id',
     'vip_subnet_id',
+    'tags',
+    'additional_vips',
 )
 
 LOAD_BALANCER_COLUMNS = (
@@ -40,6 +42,7 @@ LOAD_BALANCER_COLUMNS = (
     'project_id',
     'vip_address',
     'provisioning_status',
+    'operating_status',
     'provider')
 
 LOAD_BALANCER_STATS_ROWS = (
@@ -76,7 +79,14 @@ LISTENER_ROWS = (
     'client_authentication',
     'client_crl_container_ref',
     'allowed_cidrs',
-    'tls_ciphers')
+    'tls_ciphers',
+    'tls_versions',
+    'alpn_protocols',
+    'tags',
+    'hsts_max_age',
+    'hsts_include_subdomains',
+    'hsts_preload',
+)
 
 LISTENER_COLUMNS = (
     'id',
@@ -108,7 +118,10 @@ POOL_ROWS = (
     'ca_tls_container_ref',
     'crl_container_ref',
     'tls_enabled',
-    'tls_ciphers')
+    'tls_ciphers',
+    'tls_versions',
+    'tags',
+    'alpn_protocols')
 
 POOL_COLUMNS = (
     'id',
@@ -134,8 +147,8 @@ MEMBER_ROWS = (
     'weight',
     'monitor_port',
     'monitor_address',
-    'backup'
-)
+    'backup',
+    'tags')
 
 MEMBER_COLUMNS = (
     'id',
@@ -164,7 +177,8 @@ L7POLICY_ROWS = (
     'id',
     'operating_status',
     'name',
-    'redirect_http_code')
+    'redirect_http_code',
+    'tags')
 
 L7POLICY_COLUMNS = (
     'id',
@@ -187,7 +201,8 @@ L7RULE_ROWS = (
     'project_id',
     'type',
     'id',
-    'operating_status')
+    'operating_status',
+    'tags')
 
 L7RULE_COLUMNS = (
     'id',
@@ -219,8 +234,8 @@ MONITOR_ROWS = (
     'id',
     'operating_status',
     'http_version',
-    'domain_name'
-)
+    'domain_name',
+    'tags')
 
 MONITOR_COLUMNS = (
     'id',
@@ -236,6 +251,8 @@ QUOTA_ROWS = (
     'pool',
     'health_monitor',
     'member',
+    'l7policy',
+    'l7rule',
 )
 
 QUOTA_COLUMNS = (
@@ -245,6 +262,8 @@ QUOTA_COLUMNS = (
     'pool',
     'health_monitor',
     'member',
+    'l7policy',
+    'l7rule',
 )
 
 AMPHORA_ROWS = (
@@ -357,6 +376,7 @@ AVAILABILITYZONEPROFILE_COLUMNS = (
 )
 
 PROVISIONING_STATUS = 'provisioning_status'
+STATUS = 'status'
 
 # TCP/UDP port min/max
 MIN_PORT_NUMBER = 1
